@@ -1,5 +1,5 @@
 `plot.homals` <-
-function(x, plot.dim = c(1,2), plot.type, var.subset, main, type, xlab, ylab, 
+function(x, plot.dim = c(1,2), plot.type = "jointplot", var.subset, main, type, xlab, ylab, 
          xlim, ylim, leg.pos = "topright", ...)
 {
 #S3 plot method for objects of class "homals"
@@ -18,7 +18,7 @@ function(x, plot.dim = c(1,2), plot.type, var.subset, main, type, xlab, ylab,
 options(locatorBell = FALSE)
 if (x$ndim == 1) stop("No plots can be drawn for ndim = 1 !")
 if (length(plot.dim) !=  2) stop("plot.dim must be of length 2!")
-if (plot.type != "trfplot") {      #plot.dim are ignored for trfplot
+if ((plot.type != "trfplot") && (plot.type != "screeplot")) {      #plot.dim are ignored for trfplot
   pd1 <- plot.dim[1]
   pd2 <- plot.dim[2]
   if (pd2 > x$ndim) stop("Only",x$ndim,"dimensions were extracted!")
@@ -32,14 +32,19 @@ if (missing(var.subset)) var.subset <- 1:nvar
 
 #----------------------------------loadplot-------------------------------------
 if (plot.type == "loadplot") {
-  xycoor <- t(sapply(x$cat.loadings, function(xy) xy[1,c(pd1,pd2)]))
+  xycoor <- t(sapply(x$loadings, function(xy) xy[1,c(pd1,pd2)]))
   if (missing(main)) main1 <- "Loadings plot" else main1 <- main
-  xlim.min <- min(xycoor[,1],0)
-  xlim.max <- max(xycoor[,1],0)
-  ylim.min <- min(xycoor[,2],0)
-  ylim.max <- max(xycoor[,2],0)
-  if (missing(xlim)) xlim <- c(xlim.min,xlim.max)*1.2
-  if (missing(ylim)) ylim <- c(ylim.min,ylim.max)*1.2
+
+  #xlim.min <- min(xycoor[,1],0)
+  #xlim.max <- max(xycoor[,1],0)
+  #ylim.min <- min(xycoor[,2],0)
+  #ylim.max <- max(xycoor[,2],0)
+  #if (missing(xlim)) xlim <- c(xlim.min,xlim.max)*1.2
+  #if (missing(ylim)) ylim <- c(ylim.min,ylim.max)*1.2
+
+  if (missing(xlim)) xlim <- range(xycoor)*1.2
+  if (missing(ylim)) ylim <- range(xycoor)*1.2
+  
   plot(xycoor,type = "p", xlim = xlim, ylim = ylim, xlab = xlab, ylab = ylab, main = main1,...)
 
   for (i in 1:nvar) lines(rbind(xycoor[i,],c(0,0)),...)
@@ -56,8 +61,8 @@ if (plot.type == "loadplot") {
 if (plot.type == "catplot") {
 
   if (missing(type)) type <- "b"
-  if (missing(xlim)) xlim <- range(sapply(x$catscores, function(zz) range(zz[,pd1])))
-  if (missing(ylim)) ylim <- range(sapply(x$catscores, function(zz) range(zz[,pd2])))
+  if (missing(xlim)) xlim <- range(sapply(x$catscores, function(zz) range(zz[,c(pd1,pd2)])))
+  if (missing(ylim)) ylim <- range(sapply(x$catscores, function(zz) range(zz[,c(pd1,pd2)])))
 
   for (i in var.subset) {
     if (missing(main)) main1 <- paste("Category plot for",colnames(x$dframe[i]))  else main1 <- main
@@ -75,17 +80,20 @@ if (plot.type == "catplot") {
 if (plot.type == "jointplot") {
   xylist <- lapply(x$catscores, apply, 2, range)         
   xytab <- sapply(xylist, function(yy) yy[,c(pd1,pd2)])
-  xmin <- min(xytab[1,], x$objscores[,pd1])
-  xmax <- max(xytab[2,], x$objscores[,pd1])
-  ymin <- min(xytab[3,], x$objscores[,pd2])
-  ymax <- max(xytab[4,], x$objscores[,pd2])
+  #xmin <- min(xytab[1,], x$objscores[,pd1])
+  #xmax <- max(xytab[2,], x$objscores[,pd1])
+  #ymin <- min(xytab[3,], x$objscores[,pd2])
+  #ymax <- max(xytab[4,], x$objscores[,pd2])
     
-  if (missing(xlim)) xlim <- c(xmin, xmax)
-  if (missing(ylim)) ylim <- c(ymin, ymax)
+  #if (missing(xlim)) xlim <- c(xmin, xmax)
+  #if (missing(ylim)) ylim <- c(ymin, ymax)
+
+  xylim <- c(as.vector(xytab), as.vector(x$objscores))
+  if (missing(xlim)) xlim <- range(xylim)
+  if (missing(ylim)) ylim <- range(xylim)
   
   if (missing(main)) main <- "Joint Plot"
-  plot(x$objscores[,c(pd1,pd2)], type = "n", main = main, xlab = xlab, ylab = ylab, 
-  xlim = xlim, ylim = ylim, ...)           #draw scores
+  plot(x$objscores[,c(pd1,pd2)], type = "n", main = main, xlab = xlab, ylab = ylab, xlim = xlim, ylim = ylim, ...) 
   text(x$objscores[,c(pd1,pd2)], labels = rownames(x$dframe), col = 1)
   catcol <- rainbow(ncol(x$dframe))
   
@@ -104,8 +112,8 @@ if (plot.type == "jointplot") {
 if (plot.type == "graphplot") {
 
   if (missing(main)) main <- "Graphplot"
-  if (missing(xlim)) xlim <- range(x$objscores[,pd1])*1.2
-  if (missing(ylim)) ylim <- range(x$objscores[,pd2])*1.2
+  if (missing(xlim)) xlim <- range(x$objscores[,c(pd1,pd2)])*1.2
+  if (missing(ylim)) ylim <- range(x$objscores[,c(pd1,pd2)])*1.2
   plot(x$objscores[,c(pd1,pd2)], col = "GREEN", pch = 8, main = main, xlab = xlab, ylab = ylab, xlim = xlim, ylim = ylim,...)           #draw scores
 
   dmat <- NULL
@@ -130,12 +138,15 @@ if (plot.type == "graphplot") {
 #plots the convex hulls
 if (plot.type == "hullplot") {
 
+  if (missing(xlim)) xlim <- range(x$objscores[,c(pd1,pd2)])
+  if (missing(ylim)) ylim <- range(x$objscores[,c(pd1,pd2)])
+
   for (i in var.subset) {
     
     if (missing(main)) main1 <- paste("Hullplot for",colnames(x$dframe[i]))  else main1 <- main
     
     par("ask" = TRUE) 
-    plot(x$objscores[,c(pd1,pd2)], col = "GREEN", pch = 8, main = main1, xlab = xlab, ylab = ylab, ...)
+    plot(x$objscores[,c(pd1,pd2)], col = "GREEN", pch = 8, main = main1, xlab = xlab, ylab = ylab, xlim = xlim, ylim = ylim, ...)
        
     for (j in levels(x$dframe[,i])) 
     {
@@ -153,8 +164,8 @@ if (plot.type == "hullplot") {
 
 if (plot.type == "labplot") {
 
-  if (missing(xlim)) xlim <- range(x$objscores[,pd1])
-  if (missing(ylim)) ylim <- range(x$objscores[,pd2])
+  if (missing(xlim)) xlim <- range(x$objscores[,c(pd1,pd2)])
+  if (missing(ylim)) ylim <- range(x$objscores[,c(pd1,pd2)])
   
   for (i in var.subset) {
     if (missing(main)) main1 <- paste("Labplot for",colnames(x$dframe[i]))  else main1 <- main
@@ -175,8 +186,8 @@ if (plot.type == "lossplot") {
     z <- computeY(x$dframe[,i], x$objscores[,c(pd1,pd2)])
     k <- dim(z)[1]
     
-    if (missing(xlim)) xlim1 <- range(c(z[,2],x$catscores[[i]][,pd1])) else xlim1 <- xlim
-    if (missing(ylim)) ylim1 <- range(c(z[,2],x$catscores[[i]][,pd2])) else ylim1 <- ylim
+    if (missing(xlim)) xlim1 <- range(c(z[,2],x$catscores[[i]][,c(pd1,pd2)])) else xlim1 <- xlim
+    if (missing(ylim)) ylim1 <- range(c(z[,2],x$catscores[[i]][,c(pd1,pd2)])) else ylim1 <- ylim
     
     par("ask" = TRUE)
     plot(x$catscores[[i]][,c(pd1,pd2)], type = "p", main = main1, xlab = xlab, ylab = ylab,
@@ -199,9 +210,9 @@ if (plot.type == "lossplot") {
 
 if (plot.type == "objplot") {
     
-  if (missing(xlim)) xlim <- range(x$objscores[,pd1])
-  if (missing(ylim)) ylim <- range(x$objscores[,pd2])
-  if (missing(main)) main1 <- "Object score plot" else main1 <- main
+  if (missing(xlim)) xlim <- range(x$objscores[,c(pd1,pd2)])
+  if (missing(ylim)) ylim <- range(x$objscores[,c(pd1,pd2)])
+  if (missing(main)) main1 <- "Plot Object Scores" else main1 <- main
 
   plot(x$objscores[,c(pd1,pd2)], type = "n", main = main1, xlab = xlab, ylab = ylab, 
        xlim = xlim, ylim = ylim, ...)
@@ -215,15 +226,15 @@ if (plot.type == "objplot") {
 
 if (plot.type == "prjplot") {
 
-  if (missing(xlim)) xlim <- range(x$objscores[,pd1])
-  if (missing(ylim)) ylim <- range(x$objscores[,pd2])
+  if (missing(xlim)) xlim <- range(x$objscores[,c(pd1,pd2)])
+  if (missing(ylim)) ylim <- range(x$objscores[,c(pd1,pd2)])
   xylim <- c(min(xlim[1],ylim[1]),max(xlim[2],ylim[2]))
   
   for (i in var.subset) {
   
-    if (missing(main)) main1 <- paste("Projection plot for", colnames(x$dframe[i])) else main1 <- main
+    if (missing(main)) main1 <- paste("Projection Plot for", colnames(x$dframe[i])) else main1 <- main
      
-    a <- x$cat.loadings[[i]][c(pd1,pd2)]
+    a <- x$loadings[[i]][c(pd1,pd2)]
     
     if (x$rank.vec[i] == 1) {
       par("ask" = TRUE)
@@ -253,12 +264,15 @@ if (plot.type == "prjplot") {
 
 #-------------------------------------spanplot----------------------------------
 if (plot.type == "spanplot") {
+
+  if (missing(xlim)) xlim <- range(x$objscores[,c(pd1,pd2)])
+  if (missing(ylim)) ylim <- range(x$objscores[,c(pd1,pd2)])
   
   for (i in var.subset) {
     if (missing(main)) main1 <- paste("Span plot for", colnames(x$dframe[i])) else main1 <- main
     
     par("ask" = TRUE)
-    plot(x$objscores[,c(pd1,pd2)], col = 1, pch = 21, main = main1, xlab = xlab, ylab = ylab)
+    plot(x$objscores[,c(pd1,pd2)], col = 1, pch = 21, main = main1, xlab = xlab, ylab = ylab, xlim = xlim, ylim = ylim, ...)
     lev <- levels(x$dframe[,i])
     rb<-rainbow(length(lev))
     for (k in lev) {
@@ -279,12 +293,15 @@ if (plot.type == "spanplot") {
 
 #------------------------------------starplot-----------------------------------
 if (plot.type == "starplot") {
+
+  if (missing(xlim)) xlim <- range(x$objscores[,c(pd1,pd2)])
+  if (missing(ylim)) ylim <- range(x$objscores[,c(pd1,pd2)])
   
   for (i in var.subset) {
     if (missing(main)) main1 <- paste("Star plot for", colnames(x$dframe[i])) else main1 <- main
     
     par("ask" = TRUE)
-    plot(x$objscores[,c(pd1,pd2)], col = "BLUE", main = main1, xlab = xlab, ylab = ylab, ...)
+    plot(x$objscores[,c(pd1,pd2)], col = "BLUE", main = main1, xlab = xlab, ylab = ylab, xlim = xlim, ylim = ylim, ...)
     
     z <- computeY(x$dframe[,i], x$objscores[,c(pd1,pd2)])
     points(z, type="o", pch = 24, col = "RED")
@@ -301,15 +318,15 @@ if (plot.type == "starplot") {
 
 if (plot.type == "vecplot") {
   
-  if (missing(xlim)) xlim <- range(x$objscores[,pd1])
-  if (missing(ylim)) ylim <- range(x$objscores[,pd2])
+  if (missing(xlim)) xlim <- range(x$objscores[,c(pd1,pd2)])
+  if (missing(ylim)) ylim <- range(x$objscores[,c(pd1,pd2)])
   xylim <- c(min(xlim[1],ylim[1]),max(xlim[2],ylim[2]))
 
   for (i in var.subset) {
     if (missing(main)) main1 <- paste("Vector plot for", colnames(x$dframe[i])) else main1 <- main
      
     if (x$rank.vec[i] == 1) {
-      a <- x$cat.loadings[[i]][,c(pd1,pd2)]
+      a <- x$loadings[[i]][,c(pd1,pd2)]
       par("ask" = TRUE)
       plot(x$objscores[,c(pd1,pd2)], type = "p", main = main1, xlab = xlab, ylab = ylab,
            xlim = xylim, ylim = xylim, ...)
@@ -369,8 +386,8 @@ if (plot.type == "vorplot") {
      
      if (missing(main)) main1 <- paste("Voronoi plot for", colnames(x$dframe[i])) else main1 <- main
      z <- rbind(x$objscores[,c(pd1,pd2)],x$catscores[[i]][,c(pd1,pd2)])
-     if (missing(xlim)) xlim1 <- range(z[,1]) else xlim1 <- xlim
-     if (missing(ylim)) ylim1 <- range(z[,2]) else ylim1 <- ylim
+     if (missing(xlim)) xlim1 <- range(z) else xlim1 <- xlim
+     if (missing(ylim)) ylim1 <- range(z) else ylim1 <- ylim
    
      par("ask" = TRUE)
      plot(x$objscores[,c(pd1,pd2)], type = "n", main = main1, xlab = xlab, ylab = ylab, 
@@ -380,5 +397,33 @@ if (plot.type == "vorplot") {
   }
 }
 #----------------------------------end vorplot----------------------------------
+
+#---------------------------------- screeplot ----------------------------------
+if (plot.type == "screeplot") {
+
+   if (missing(main)) main <- "Scree plot"
+   if (missing(xlab)) xlab <- "Dimension"
+   if (missing(ylab)) ylab <- "Eigenvalue"
+
+  plot(1:x$ndim, x$eigenvalues, type = "b", xlab = xlab, ylab = ylab, main = main, xaxt = "n", ...)
+  axis(1, at = 1:x$ndim, labels = 1:x$ndim)
+}  
+#-------------------------------- end screeplot --------------------------------
+ 
+#----------------------------------- dmplot ------------------------------------
+if (plot.type == "dmplot") {
+
+   if (missing(main)) main <- "Discrminination Measures"
+   xylim <- range(x$discrim[,c(pd1, pd2)])
+   if (missing(xlim)) xlim <- xylim
+   if (missing(ylim)) ylim <- xylim
+
+   plot(x$discrim[,c(pd1,pd2)], type = "p", main = main, xlab = xlab, ylab = ylab, xlim = xlim, ylim = ylim, ...)
+   for (i in 1:nvar) lines(rbind(x$discrim[i,c(pd1,pd2)],c(0,0)))
+   text(x$discrim[,c(pd1,pd2)], rownames(x$discrim), pos = 3)
+}  
+
+#-------------------------------- end dmplot -----------------------------------
+
 }
 
